import { EventEmitter, TemplateRef } from '@angular/core';
import * as i0 from "@angular/core";
/**
 * Inserts a help button beside an element, such as a field, to display contextual information about the element.
 */
export declare class SkyHelpInlineComponent {
    #private;
    /**
     * The ID of the element that the help inline button controls.
     * This property [supports accessibility rules for disclosures](https://www.w3.org/TR/wai-aria-practices-1.1/#disclosure).
     * For more information about the `aria-controls` attribute, see the [WAI-ARIA definition](https://www.w3.org/TR/wai-aria/#aria-controls).
     */
    ariaControls: string | undefined;
    /**
     * Whether an element or popover controlled by the help inline button is expanded. If popoverContent is specified,
     * this value is overridden with popover expanded status.
     */
    ariaExpanded: boolean | undefined;
    /**
     * The ARIA label for the help inline button. This sets the button's `aria-label` to provide a text equivalent for screen readers.
     * Will be overridden if label text is set.
     * @default "Show help content"
     */
    ariaLabel: string | undefined;
    /**
     * A unique key that identifies the [global help](https://developer.blackbaud.com/skyux/learn/develop/global-help) content to display when the button is clicked.
     */
    helpKey: string | undefined;
    /**
     * The ID of the element associated with the help inline button. This is used to set the button's `aria-labelledby`
     * to provides a text equivalent for screen readers. Takes precedence over `ariaLabel` and `labelText` inputs.
     * @internal
     */
    labelledBy: string | undefined;
    /**
     * The label of the component the help inline button is attached to.
     */
    set labelText(value: string | undefined);
    /**
     * The content of the help popover. When specified, clicking the help inline button opens a popover with this content and optional title.
     */
    popoverContent: string | TemplateRef<unknown> | undefined;
    /**
     * The title of the help popover. This property only applies when `popoverContent` is
     * also specified.
     */
    popoverTitle: string | undefined;
    /**
     * Fires when the user clicks the help inline button.
     */
    actionClick: EventEmitter<void>;
    protected readonly defaultAriaLabel: import("@angular/core").Signal<string | undefined>;
    protected readonly labelTextResolved: import("@angular/core").Signal<string | undefined>;
    protected onClick(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<SkyHelpInlineComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SkyHelpInlineComponent, "sky-help-inline", never, { "ariaControls": { "alias": "ariaControls"; "required": false; }; "ariaExpanded": { "alias": "ariaExpanded"; "required": false; }; "ariaLabel": { "alias": "ariaLabel"; "required": false; }; "helpKey": { "alias": "helpKey"; "required": false; }; "labelledBy": { "alias": "labelledBy"; "required": false; }; "labelText": { "alias": "labelText"; "required": false; }; "popoverContent": { "alias": "popoverContent"; "required": false; }; "popoverTitle": { "alias": "popoverTitle"; "required": false; }; }, { "actionClick": "actionClick"; }, never, never, true, never>;
}
